@@ -15,14 +15,11 @@
 General constants.
 """
 
-SERVICE = 'org.storage.stratis1'
-TOP_OBJECT = '/org/storage/stratis1'
-MANAGER_INTERFACE = 'org.storage.stratis1.Manager'
+SERVICE = "org.storage.stratis1"
+TOP_OBJECT = "/org/storage/stratis1"
 
 SECTOR_SIZE = 512
 
-# This string is used in all instances where an uninterpretable value is
-# retrieved from the API.
-UNKNOWN_VALUE_MARKER = "???"
-
-DBUS_TIMEOUT_SECONDS = 120
+FILESYSTEM_INTERFACE = "org.storage.stratis1.filesystem"
+POOL_INTERFACE = "org.storage.stratis1.pool"
+BLOCKDEV_INTERFACE = "org.storage.stratis1.blockdev"
