@@ -19,27 +19,26 @@ from .._stratisd_constants import RedundancyCodes
 
 from ._connection import get_object
 from ._constants import TOP_OBJECT
-from ._data import Manager
 
 
-class StratisActions():
+class StratisActions:
     """
     Stratis actions.
     """
 
     @staticmethod
-    def list_stratisd_redundancy(namespace):
+    def list_stratisd_redundancy(_namespace):
         """
         List the stratisd redundancy designations.
         """
-        # pylint: disable=unused-argument
         for code in RedundancyCodes:
             print("%s: %d" % (code.name, code.value))
 
     @staticmethod
-    def list_stratisd_version(namespace):
+    def list_stratisd_version(_namespace):
         """
         List the stratisd version.
         """
-        # pylint: disable=unused-argument
+        from ._data import Manager
+
         print("%s" % Manager.Properties.Version.Get(get_object(TOP_OBJECT)))
