@@ -24,15 +24,10 @@ from .._stratisd_constants import StratisdErrors
 from ._connection import get_object
 from ._constants import TOP_OBJECT
 from ._constants import SECTOR_SIZE
-from ._data import Manager
-from ._data import MOPool
-from ._data import ObjectManager
-from ._data import Pool
-from ._data import pools
 from ._formatting import print_table
 
 
-class TopActions():
+class TopActions:
     """
     Top level actions.
     """
@@ -44,16 +39,20 @@ class TopActions():
 
         :raises StratisCliEngineError:
         """
+        from ._data import Manager
+
         proxy = get_object(TOP_OBJECT)
 
         (_, rc, message) = Manager.Methods.CreatePool(
-            proxy, {
-                'name': namespace.pool_name,
-                'redundancy': (True, 0),
-                'devices': namespace.blockdevs
-            })
+            proxy,
+            {
+                "name": namespace.pool_name,
+                "redundancy": (True, 0),
+                "devices": namespace.blockdevs,
+            },
+        )
 
-        if rc != StratisdErrors.OK:
+        if rc != StratisdErrors.OK:  # pragma: no cover
             raise StratisCliEngineError(rc, message)
 
     @staticmethod
@@ -63,18 +62,27 @@ class TopActions():
 
         :raises StratisCliEngineError:
         """
+        from ._data import MOPool
+        from ._data import ObjectManager
+        from ._data import pools
+
         proxy = get_object(TOP_OBJECT)
 
         managed_objects = ObjectManager.Methods.GetManagedObjects(proxy, {})
         mopools = (MOPool(info) for _, info in pools().search(managed_objects))
-        tables = [[
-            mopool.Name(),
-            str(Range(mopool.TotalPhysicalSize(), SECTOR_SIZE)),
-            str(Range(mopool.TotalPhysicalUsed(), SECTOR_SIZE)),
-        ] for mopool in mopools]
-        print_table(['Name', 'Total Physical Size', 'Total Physical Used'],
-                    sorted(tables, key=lambda entry: entry[0]),
-                    ['<', '>', '>'])
+        tables = [
+            [
+                mopool.Name(),
+                str(Range(mopool.TotalPhysicalSize(), SECTOR_SIZE)),
+                str(Range(mopool.TotalPhysicalUsed(), SECTOR_SIZE)),
+            ]
+            for mopool in mopools
+        ]
+        print_table(
+            ["Name", "Total Physical Size", "Total Physical Used"],
+            sorted(tables, key=lambda entry: entry[0]),
+            ["<", ">", ">"],
+        )
 
     @staticmethod
     def destroy_pool(namespace):
@@ -85,16 +93,24 @@ class TopActions():
 
         :raises StratisCliEngineError:
         """
+        from ._data import Manager
+        from ._data import ObjectManager
+        from ._data import pools
+
         proxy = get_object(TOP_OBJECT)
         managed_objects = ObjectManager.Methods.GetManagedObjects(proxy, {})
         (pool_object_path, _) = next(
-            pools(props={
-                'Name': namespace.pool_name
-            }).require_unique_match(True).search(managed_objects))
+            pools(props={"Name": namespace.pool_name})
+            .require_unique_match(True)
+            .search(managed_objects)
+        )
 
-        (_, rc, message) = \
-           Manager.Methods.DestroyPool(proxy, {'pool': pool_object_path})
+        (_, rc, message) = Manager.Methods.DestroyPool(
+            proxy, {"pool": pool_object_path}
+        )
 
+        # This branch can be covered, since the engine will return an error
+        # if the pool can not be destroyed because it has filesystems.
         if rc != StratisdErrors.OK:
             raise StratisCliEngineError(rc, message)
 
@@ -103,49 +119,67 @@ class TopActions():
         """
         Rename a pool.
         """
+        from ._data import ObjectManager
+        from ._data import Pool
+        from ._data import pools
+
         proxy = get_object(TOP_OBJECT)
         managed_objects = ObjectManager.Methods.GetManagedObjects(proxy, {})
         (pool_object_path, _) = next(
-            pools(props={
-                'Name': namespace.current
-            }).require_unique_match(True).search(managed_objects))
+            pools(props={"Name": namespace.current})
+            .require_unique_match(True)
+            .search(managed_objects)
+        )
 
         (_, rc, message) = Pool.Methods.SetName(
-            get_object(pool_object_path), {'name': namespace.new})
+            get_object(pool_object_path), {"name": namespace.new}
+        )
 
-        if rc != StratisdErrors.OK:
+        if rc != StratisdErrors.OK:  # pragma: no cover
             raise StratisCliEngineError(rc, message)
 
     @staticmethod
-    def add_data_device(namespace):
+    def add_data_devices(namespace):
         """
-        Add a device to a pool.
+        Add specified data devices to a pool.
         """
+        from ._data import ObjectManager
+        from ._data import Pool
+        from ._data import pools
+
         proxy = get_object(TOP_OBJECT)
         managed_objects = ObjectManager.Methods.GetManagedObjects(proxy, {})
         (pool_object_path, _) = next(
-            pools(props={
-                'Name': namespace.pool_name
-            }).require_unique_match(True).search(managed_objects))
+            pools(props={"Name": namespace.pool_name})
+            .require_unique_match(True)
+            .search(managed_objects)
+        )
 
         (_, rc, message) = Pool.Methods.AddDataDevs(
-            get_object(pool_object_path), {'devices': namespace.device})
-        if rc != StratisdErrors.OK:
+            get_object(pool_object_path), {"devices": namespace.blockdevs}
+        )
+        if rc != StratisdErrors.OK:  # pragma: no cover
             raise StratisCliEngineError(rc, message)
 
     @staticmethod
-    def add_cache_device(namespace):
+    def add_cache_devices(namespace):
         """
-        Add a device to a pool.
+        Add specified cache devices to a pool.
         """
+        from ._data import ObjectManager
+        from ._data import Pool
+        from ._data import pools
+
         proxy = get_object(TOP_OBJECT)
         managed_objects = ObjectManager.Methods.GetManagedObjects(proxy, {})
         (pool_object_path, _) = next(
-            pools(props={
-                'Name': namespace.pool_name
-            }).require_unique_match(True).search(managed_objects))
+            pools(props={"Name": namespace.pool_name})
+            .require_unique_match(True)
+            .search(managed_objects)
+        )
 
         (_, rc, message) = Pool.Methods.AddCacheDevs(
-            get_object(pool_object_path), {'devices': namespace.device})
-        if rc != StratisdErrors.OK:
+            get_object(pool_object_path), {"devices": namespace.blockdevs}
+        )
+        if rc != StratisdErrors.OK:  # pragma: no cover
             raise StratisCliEngineError(rc, message)
